# misugaru

### Installation

Install latest from the GitHub
[repository](https://github.com/msaid-de/misugaru):

``` sh
git clone git+https://github.com/msaid-de/misugaru.git
cd misugaro && uvx pip install misugaru
```

or from [pypi](https://pypi.org/project/misugaru/)

``` sh
$ pip install misugaru
```

### Documentation

Documentation can be found hosted on this GitHub
[repository](https://github.com/msaid-de/misugaru)’s
[pages](https://msaid-de.github.io/misugaru/). Additionally you can find
package manager specific guidelines on
[pypi](https://pypi.org/project/misugaru/) respectively.

## How to use

``` python
misugaru /path/to/psms.parquet /path/to/out/dir
```
